<?lsp

local fmt=string.format
local d

function openDat(mode)
   return app.bio:open("server.cert.dat",mode)
end

function mkOpenSSLConfig()
local cfgfmt=[[
[ req ]
distinguished_name = req_distinguished_name

[ req_distinguished_name ]
countryName            = Country Name (2 letter code)
stateOrProvinceName    = State or Province Name (full name)
localityName           = Locality Name (eg, city)
0.organizationName     = Organization Name (eg, company)
organizationalUnitName = Organizational Unit Name (eg, section)
commonName             = Common Name (eg, YOUR name)
emailAddress           = Email Address

#replace the following
countryName_default            = %s
stateOrProvinceName_default    = %s
localityName_default           = %s
0.organizationName_default     = %s
organizationalUnitName_default = %s
commonName_default             = %s
emailAddress_default           = %s
]]
   local fp = app.bio:open("server.cert.cnf","w")
   if fp then
      fp:write(fmt(cfgfmt,
                   d.countryName,
                   d.stateOrProvinceName,
                   d.localityName,
                   d.organizationName,
                   d.organizationalUnitName,
                   d.commonName,
                   d.emailAddress))
      fp:close()
   end
end


local isPost = request:method() == "POST"
if isPost then
   local ok=true
   d = request:data()
   for k,v in pairs(d) do
      v=app.trim(v)
      if not v then
         ok=false
         break
      end
      d[k]=v
   end
   if #d.countryName ~= 2 then
      ok=false
   end
   if ok then
      local fp = openDat("w");
      if fp then
         fp:write(json.encode(d))
         fp:close()
      end
      mkOpenSSLConfig()
      local ok,err = app.openssl("req -new -key",
                                 app.bio:realpath("server.key"),
                                 "-out ", app.bio:realpath("server.csr"),
                                 " -batch -config",
                                 app.bio:realpath("server.cert.cnf"),
                                 "-nodes -sha1")
      if ok then
         response:forward".SigningRequest.lsp"
      else
         print("<pre>",err,"</pre></body></html>")
         return
      end
   end
else
   local fp = openDat("r");
   if fp then
      d = json.decode(fp:read"*a")
      fp:close()
   end
   if not d then
      d={
         countryName="",
         stateOrProvinceName="",
         localityName="",
         organizationName="",
         organizationalUnitName="",
         commonName="",
         emailAddress=""
      }
   end
end


title="Generate a Certificate Signing Request (CSR)"
headerdata=[[
<style>
#help {
  position: absolute;
  display:none;
  left: 10px;
  background: white;
  border: solid 1px;
  padding: 1em;
  z-index:1;
} 
</style>
]]
response:include"/rtl/.header.lsp"
if isPost then
   print("<p style='color:red'>Some information is incorrect or missing. Please correct your entries and try again.</p>")
end
?>
<script type="text/javascript" src="help.js"></script>
<div id="help"></div>
<table><tr><td>
<form method="post">
<table>
<tr><td>Country Name:</td>
  <td><input name="countryName" value="<?lsp=d.countryName?>"></input></td>
  <td><img hlp='countryName' src='/rtl/bindows/html/images/questionmark.16.gif' alt=''/></td></tr>
<tr><td>State or Province:</td>
  <td><input name="stateOrProvinceName" value="<?lsp=d.stateOrProvinceName?>"></input></td>
  <td><img hlp='stateOrProvinceName' src='/rtl/bindows/html/images/questionmark.16.gif' alt=''/></td></tr>
<tr><td>City or Locality:</td>
  <td><input name="localityName" value="<?lsp=d.localityName?>"></input></td>
  <td><img hlp='localityName' src='/rtl/bindows/html/images/questionmark.16.gif' alt=''/></td></tr>
<tr><td>Organization Name:</td>
  <td><input name="organizationName" value="<?lsp=d.organizationName?>"></input></td>
  <td><img hlp='organizationName' src='/rtl/bindows/html/images/questionmark.16.gif' alt=''/></td></tr>
<tr><td>Organizational Unit:</td>
  <td><input name="organizationalUnitName" value="<?lsp=d.organizationalUnitName?>"></input></td> 
  <td><img hlp='organizationalUnitName' src='/rtl/bindows/html/images/questionmark.16.gif' alt=''/></td></tr>
<tr><td>Common Name:</td>
  <td><input name="commonName" value="<?lsp=d.commonName?>"></input></td>
  <td><img hlp='commonName' src='/rtl/bindows/html/images/questionmark.16.gif' alt=''/></td></tr>
<tr><td>Email Address:</td>
  <td><input name="emailAddress" value="<?lsp=d.emailAddress?>"></input></td>
  <td></td></tr>
</table>
<input type="submit" value="Generate CSR"></input>
</form>
</td>
<td valign="top">
<div style="padding:1em 0 0 4em">
<img hlp='intro' src='/rtl/bindows/html/images/questionmark.32.gif' alt=''/>
<p>For help, hover your mouse over the help buttons.</p>
</p>
</div>
</td>
</tr></table>
<?lsp
title="sslcert"
response:include"/rtl/.footer.lsp"
?>
